pub struct SecretString(/* private fields */);Expand description
Implementations
Sourceimpl SecretString
impl SecretString
Sourcepub fn expose(&self) -> &str
pub fn expose(&self) -> &str
Provide read-only access to the underlying secret.
Callers must not log, store, or otherwise persist the returned slice.
Sourcepub fn into_inner(self) -> String
pub fn into_inner(self) -> String
Consume self and return the underlying secret, e.g. to move it into
another owned value without an extra clone.
Callers must not log, store, or otherwise persist the returned value.